# Moy Nalog


Usage example:

```python
import asyncio
from moy_nalog import MoyNalog

nalog = MoyNalog("inn", "pass")


async def main():
    await data.add_income(
        "Предоставление информационных услуг #970/2495", amount=1000, quantity=1
    )


asyncio.run(main())
```